@@ -1,6 +1,6 @@
 package sparklyr
 
-object ClassUtils {
+class ClassUtils {
   def getClassLoader: ClassLoader = {
     Option(Thread.currentThread().getContextClassLoader).getOrElse(getClass.getClassLoader)
   }
