@@ -7,7 +7,7 @@ import org.apache.spark.sql.SparkSession
 import org.apache.spark.sql.types._
 import org.apache.spark.TaskContext
 
-import scala.collection.JavaConversions._
+import scala.jdk.CollectionConverters._
 
 object WorkerHelper {
   def computeRdd(
